pycrunch
========

A Python client library for Crunch.io.


Using pycrunch
--------------

To use pycrunch in your project, run 

    # python setup.py develop

This will make the code in this directory available to other projects.

Running tests
-------------

You will need a Python environment with Nose installed, if you don't have one:

    $ pip install nose

Then from the repo root run

    $ nosetests pycrunch/tests/
